.. :changelog:

History
-------

.. to_doc

---------------------
0.2.0 (2016-08-15)
---------------------

* Add tool generate a tool list from a Galaxy workflow file
  (thanks to @drosofff).
* Fix various code quality issues including adding beta support
  for Python 3 (thanks in part to @mvdbeek).

---------------------
0.1.0 (2016-06-15)
---------------------

* Setup project, pull in scripts from `ansible-galaxy-tools
  <https://github.com/galaxyproject/ansible-galaxy-tools>`__
  and adapt them for usage as a library.

.. _bioblend: https://github.com/galaxyproject/bioblend/
.. _nose: https://nose.readthedocs.org/en/latest/
